{% extends "base.html" %}

{% block title %}{{ project_name }} - Claude Code Archive{% endblock %}

{% block content %}
        <h1><a href="../index.html" style="color: inherit; text-decoration: none;">Claude Code Archive</a> / {{ project_name }}</h1>
        <p style="color: var(--text-muted); margin-bottom: 24px;">{{ session_count }} session{% if session_count != 1 %}s{% endif %}</p>

        {% for session in sessions %}
        <div class="index-item">
            <a href="{{ session.name }}/index.html">
                <div class="index-item-header">
                    <span class="index-item-number">{{ session.date }}</span>
                    <span style="color: var(--text-muted);">{{ "%.0f"|format(session.size_kb) }} KB</span>
                </div>
                <div class="index-item-content">
                    <p style="margin: 0;">{{ session.summary[:100] }}{% if session.summary|length > 100 %}...{% endif %}</p>
                </div>
            </a>
        </div>
        {% endfor %}

        <div style="margin-top: 24px;">
            <a href="../index.html" class="pagination" style="display: inline-block; padding: 8px 16px; background: var(--user-border); color: white; text-decoration: none; border-radius: 6px;">Back to Archive</a>
        </div>
{%- endblock %}
