{% extends "base.html" %}

{% block title %}{{ transcript_title }}{% if session_label %} - {{ session_label }}{% endif %} - page {{ page_num }}{% endblock %}

{% block content %}
        <h1>
            <a href="index.html" style="color: inherit; text-decoration: none;">{{ transcript_title }}</a>
            {% if session_label %}<span style="color: var(--text-muted); font-weight: 400;"> — {{ session_label }}</span>{% endif %}
            - page {{ page_num }}/{{ total_pages }}
        </h1>
        {{ pagination_html|safe }}
        {{ messages_html|safe }}
        {{ pagination_html|safe }}
{%- endblock %}
